pub enum InputEvent {
Show 119 variants
AssistantMessage(String),
AddUserMessage(String),
StreamAssistantMessage(Uuid, String),
RunToolCall(ToolCall),
ToolResult(ToolCallResult),
StreamToolResult(ToolCallResultProgress),
StartLoadingOperation(LoadingOperation),
EndLoadingOperation(LoadingOperation),
InputChanged(char),
ShellMode,
RunShellCommand(String),
RunShellWithCommand(String),
GetStatus(String),
BillingInfoLoaded(BillingResponse),
Error(String),
SetSessions(Vec<SessionInfo>),
InputBackspace,
InputChangedNewline,
InputSubmitted,
InputSubmittedWith(String),
InputSubmittedWithColor(String, Color),
MessageToolCalls(Vec<ToolCall>),
ScrollUp,
ScrollDown,
PageUp,
PageDown,
DropdownUp,
DropdownDown,
Up,
Down,
Quit,
HandleEsc,
HandleReject(Option<String>, bool, Option<Color>),
CursorLeft,
CursorRight,
ToggleCursorVisible,
Resized(u16, u16),
ShowConfirmationDialog(ToolCall),
HasUserMessage,
Tab,
ToggleApprovalStatus,
ShellOutput(String),
ShellError(String),
ShellWaitingForInput,
ShellCompleted(i32),
ShellClear,
ShellKill,
HandlePaste(String),
HandleClipboardImagePaste,
InputDelete,
InputDeleteWord,
InputCursorStart,
InputCursorEnd,
InputCursorPrevWord,
InputCursorNextWord,
ToggleAutoApprove,
AutoApproveCurrentTool,
ToggleDialogFocus,
RetryLastToolCall,
InteractiveStallDetected(String),
AttemptQuit,
ToggleCollapsedMessages,
ShowFileChangesPopup,
FileChangesRevertFile,
FileChangesRevertAll,
FileChangesOpenEditor,
EmergencyClearTerminal,
ToggleMouseCapture,
OpenFileInEditor,
ApprovalPopupNextTab,
ApprovalPopupPrevTab,
ApprovalPopupToggleApproval,
ApprovalPopupSubmit,
ApprovalPopupEscape,
ApprovalBarApproveAll,
ApprovalBarRejectAll,
ApprovalBarSelectAction(usize),
ApprovalBarApproveSelected,
ApprovalBarRejectSelected,
ApprovalBarNextAction,
ApprovalBarPrevAction,
ApprovalBarCollapse,
ShowProfileSwitcher,
ProfilesLoaded(Vec<String>, String),
ProfileSwitchRequested(String),
ProfileSwitchProgress(String),
ProfileSwitchComplete(String),
ProfileSwitchFailed(String),
ShowCommandPalette,
CommandPaletteSearchInputChanged(char),
CommandPaletteSearchBackspace,
ProfileSwitcherSelect,
ProfileSwitcherCancel,
ShowShortcuts,
ShortcutsCancel,
ShowRulebookSwitcher,
RulebooksLoaded(Vec<ListRuleBook>),
CurrentRulebooksLoaded(Vec<String>),
RulebookSwitcherSelect,
RulebookSwitcherToggle,
RulebookSwitcherCancel,
RulebookSwitcherConfirm,
RulebookSwitcherSelectAll,
RulebookSwitcherDeselectAll,
RulebookSearchInputChanged(char),
RulebookSearchBackspace,
HandleCtrlS,
ToggleMoreShortcuts,
StreamUsage(LLMTokenUsage),
RequestTotalUsage,
TotalUsage(LLMTokenUsage),
StreamModel(LLMModel),
ToggleSidePanel,
SidePanelNextSection,
SidePanelToggleSection,
MouseClick(u16, u16),
RefreshBoardTasks,
BoardTasksLoaded(FetchTasksResult),
BoardTasksError(String),
}Variants
AssistantMessage(String)
AddUserMessage(String)
StreamAssistantMessage(Uuid, String)
RunToolCall(ToolCall)
ToolResult(ToolCallResult)
StreamToolResult(ToolCallResultProgress)
StartLoadingOperation(LoadingOperation)
EndLoadingOperation(LoadingOperation)
InputChanged(char)
ShellMode
RunShellCommand(String)
RunShellWithCommand(String)
Spawn the user’s shell and then execute a command in it (for interactive stall recovery)
GetStatus(String)
BillingInfoLoaded(BillingResponse)
Error(String)
SetSessions(Vec<SessionInfo>)
InputBackspace
InputChangedNewline
InputSubmitted
InputSubmittedWith(String)
InputSubmittedWithColor(String, Color)
MessageToolCalls(Vec<ToolCall>)
ScrollUp
ScrollDown
PageUp
PageDown
DropdownUp
DropdownDown
Up
Down
Quit
HandleEsc
HandleReject(Option<String>, bool, Option<Color>)
CursorLeft
CursorRight
ToggleCursorVisible
Resized(u16, u16)
ShowConfirmationDialog(ToolCall)
HasUserMessage
Tab
ToggleApprovalStatus
ShellOutput(String)
ShellError(String)
ShellWaitingForInput
ShellCompleted(i32)
ShellClear
ShellKill
HandlePaste(String)
HandleClipboardImagePaste
Ctrl+V clipboard image paste (non-text, via system clipboard).
InputDelete
InputDeleteWord
InputCursorStart
InputCursorEnd
InputCursorPrevWord
InputCursorNextWord
ToggleAutoApprove
AutoApproveCurrentTool
ToggleDialogFocus
RetryLastToolCall
InteractiveStallDetected(String)
Interactive stall detected - automatically switch to shell mode and fire the command
AttemptQuit
ToggleCollapsedMessages
ShowFileChangesPopup
FileChangesRevertFile
FileChangesRevertAll
FileChangesOpenEditor
EmergencyClearTerminal
ToggleMouseCapture
OpenFileInEditor
ApprovalPopupNextTab
ApprovalPopupPrevTab
ApprovalPopupToggleApproval
ApprovalPopupSubmit
ApprovalPopupEscape
ApprovalBarApproveAll
ApprovalBarRejectAll
ApprovalBarSelectAction(usize)
ApprovalBarApproveSelected
ApprovalBarRejectSelected
ApprovalBarNextAction
ApprovalBarPrevAction
ApprovalBarCollapse
ShowProfileSwitcher
ProfilesLoaded(Vec<String>, String)
ProfileSwitchRequested(String)
ProfileSwitchProgress(String)
ProfileSwitchComplete(String)
ProfileSwitchFailed(String)
ShowCommandPalette
CommandPaletteSearchInputChanged(char)
CommandPaletteSearchBackspace
ProfileSwitcherSelect
ProfileSwitcherCancel
ShowShortcuts
ShortcutsCancel
ShowRulebookSwitcher
RulebooksLoaded(Vec<ListRuleBook>)
CurrentRulebooksLoaded(Vec<String>)
RulebookSwitcherSelect
RulebookSwitcherToggle
RulebookSwitcherCancel
RulebookSwitcherConfirm
RulebookSwitcherSelectAll
RulebookSwitcherDeselectAll
RulebookSearchInputChanged(char)
RulebookSearchBackspace
HandleCtrlS
ToggleMoreShortcuts
StreamUsage(LLMTokenUsage)
RequestTotalUsage
TotalUsage(LLMTokenUsage)
StreamModel(LLMModel)
ToggleSidePanel
SidePanelNextSection
SidePanelToggleSection
MouseClick(u16, u16)
RefreshBoardTasks
BoardTasksLoaded(FetchTasksResult)
BoardTasksError(String)